@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: pgp.c,v 2.1 1998/12/30 07:58:40 roessler Exp $";
 /*
  * Copyright (C) 1996,1997 Michael R. Elkins <me@cs.hmc.edu>
  * Copyright (c) 1998 Thomas Roessler <roessler@guug.de>
@@ -1023,7 +1022,7 @@ static void convert_to_7bit (BODY *a)
       a->encoding = ENCQUOTEDPRINTABLE;
     else if (a->encoding == ENCBINARY)
       a->encoding = ENCBASE64;
-    else if (a->content && (a->content->from || (a->content->space && option (OPTPGPSTRICTENC))))
+    else if (a->content && a->encoding != ENCBASE64 && (a->content->from || (a->content->space && option (OPTPGPSTRICTENC))))
       a->encoding = ENCQUOTEDPRINTABLE;
     a = a->next;
   }
